@@ -61,41 +61,44 @@ calcSVbound <- function(Y1, Y0, Tr, S, U, V, estimand, obsProb)
   {
     # RR_(UY|S=1), max_t[max_u(P(Y = 1|T = t, I_S = 1, U = u))/min_u(P(Y = 1|T = t, I_S = 1, U = u))].
     RR_UY_S1 = max((max(Y1[1, ]) / min(Y1[1, ])), (max(Y0[1, ]) / min(Y0[1, ])))
-    # RR_(TU|S=1), max_u(P(U = u|T = 1, I_S = 1)/P(U = u|T = 0, I_S = 1)).
-    RR_TU_S1 = max(pUT1S1 / pUT0S1)
+    # RR_(TU|1), max_u(P(U = u|T = 1, I_S = 1)/P(U = u|T = 0, I_S = 1)).
+    RR_TU_1 = max(pUT1S1 / pUT0S1)
+    # RR_(TU|0), max_u(P(U = u|T = 0, I_S = 1)/P(U = u|T = 1, I_S = 1)).
+    RR_TU_0 = max(pUT0S1 / pUT1S1)
 
-    # BF_U = (RR_(UY|S=1) * RR_(TU|S=1)) / (RR_(UY|S=1) + RR_(TU|S=1) - 1).
-    BF_U = (RR_UY_S1 * RR_TU_S1) / (RR_UY_S1 + RR_TU_S1 - 1)
+    # BF_1 = (RR_(UY|S=1) * RR_(TU|1)) / (RR_(UY|S=1) + RR_(TU|1) - 1).
+    BF_1 = (RR_UY_S1 * RR_TU_1) / (RR_UY_S1 + RR_TU_1 - 1)
+    # BF_0 = (RR_(UY|S=1) * RR_(TU|0)) / (RR_(UY|S=1) + RR_(TU|0) - 1).
+    BF_0 = (RR_UY_S1 * RR_TU_0) / (RR_UY_S1 + RR_TU_0 - 1)
 
-    # Bounds for the relative risk and risk difference.
-    boundRR_s = round(BF_U, digits = 14)
-    boundRD_s = round(max(pY_T0 * (BF_U - 1), pY_T1 * (1 - 1 / BF_U)), digits = 14)
 
     # The return vector.
-    if(estimand == "RD_sub"){returnVec = round(c(boundRD_s, BF_U, RR_UY_S1, RR_TU_S1, pY_T1,pY_T0), 4)
-    }else{returnVec = round(c(boundRR_s, BF_U, RR_UY_S1, RR_TU_S1), 4)}
+    if(estimand == "RD_sub"){returnVec = round(c(BF_1, BF_0, RR_UY_S1, RR_TU_1, RR_TU_0, pY_T1,pY_T0), 4)
+    }else{returnVec = round(c(BF_1, BF_0, RR_UY_S1, RR_TU_1, RR_TU_0), 4)}
   }else{ #The total population.
     # RR_(UY|T=1), max_u(P(Y = 1|T = 1, U = u)) / min_u(P(Y = 1|T = 1, U = u))
     RR_UY_T1 = max(Y1[1, ]) / min(Y1[1, ])
     # RR_(UY|T=0), max_u(P(Y = 1|T = 0, U = u)) / min_u(P(Y = 1|T = 0, U = u))
     RR_UY_T0 = max(Y0[1, ]) / min(Y0[1, ])
 
-    # RR_(SU|T=1), max_u(P(U = u|T = 1, I_S = 1) / P(U = u|T = 1, I_S = 0)).
-    RR_SU_T1 = max(pUT1S1 / pUT1S0)
-    # RR_(SU|T=0), max_u(P(U = u|T = 0, I_S = 0) / P(U = u|T = 0, I_S = 1)).
-    RR_SU_T0 = max(pUT0S0 / pUT0S1)
+    # RR_(SU|11), max_u(P(U = u|T = 1, I_S = 1) / P(U = u|T = 1, I_S = 0)).
+    RR_SU_11 = max(pUT1S1 / pUT1S0)
+    # RR_(SU|00), max_u(P(U = u|T = 0, I_S = 0) / P(U = u|T = 0, I_S = 1)).
+    RR_SU_00 = max(pUT0S0 / pUT0S1)
+    # RR_(SU|10), max_u(P(U = u|T = 1, I_S = 0) / P(U = u|T = 1, I_S = 1)).
+    RR_SU_10 = max(pUT1S0 / pUT1S1)
+    # RR_(SU|01), max_u(P(U = u|T = 0, I_S = 1) / P(U = u|T = 0, I_S = 0)).
+    RR_SU_01 = max(pUT0S1 / pUT0S0)
 
-    # BF_1 and BF_0.
-    BF1 = (RR_UY_T1 * RR_SU_T1) / (RR_UY_T1 + RR_SU_T1 - 1)
-    BF0 = (RR_UY_T0 * RR_SU_T0) / (RR_UY_T0 + RR_SU_T0 - 1)
-
-    # The bounds for the relative risk and risk difference.
-    boundRR_tot = BF1 * BF0
-    boundRD_tot = BF1 - pY_T1 / BF1 + pY_T0 * BF0
+    # BF_11, BF_00, BF_01, and BF_10.
+    BF11 = (RR_UY_T1 * RR_SU_11) / (RR_UY_T1 + RR_SU_11 - 1)
+    BF00 = (RR_UY_T0 * RR_SU_00) / (RR_UY_T0 + RR_SU_00 - 1)
+    BF01 = (RR_UY_T0 * RR_SU_01) / (RR_UY_T0 + RR_SU_01 - 1)
+    BF10 = (RR_UY_T1 * RR_SU_10) / (RR_UY_T1 + RR_SU_10 - 1)
 
     # The return vector.
-    if(estimand=="RR_tot"){returnVec = round(c(boundRR_tot, BF1, BF0, RR_UY_T1, RR_UY_T0, RR_SU_T1, RR_SU_T0), 4)
-    }else{returnVec = round(c(boundRD_tot, BF1, BF0, RR_UY_T1, RR_UY_T0, RR_SU_T1, RR_SU_T0, pY_T1, pY_T0), 4)}
+    if(estimand=="RR_tot"){returnVec = round(c(BF11, BF00, BF10, BF01, RR_UY_T1, RR_UY_T0, RR_SU_11, RR_SU_00, RR_SU_10, RR_SU_01), 4)
+    }else{returnVec = round(c(BF11, BF00, BF10, BF01, RR_UY_T1, RR_UY_T0, RR_SU_11, RR_SU_00, RR_SU_10, RR_SU_01, pY_T1, pY_T0), 4)}
   }
 
   return(returnVec)
